#
# spec file for package python-deap
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-deap
Version:        1.4.1
Release:        2.3
Summary:        Distributed Evolutionary Algorithms in Python
License:        LGPL-3.0-only
URL:            https://github.com/DEAP/deap
Source:         https://files.pythonhosted.org/packages/source/d/deap/deap-%{version}.tar.gz
BuildRequires:  %{python_module numpy-devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
Requires:       python-numpy
%python_subpackages

%description
DEAP is intended to be an easy to use distributed evolutionary algorithm
library in the Python language. Its two main components are modular and
can be used separately. The first module is a Distributed Task Manager
(DTM), which is intended to run on cluster of computers. The second
part is the Evolutionary Algorithms in Python (EAP) framework.

%prep
%setup -q -n deap-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%doc README.md
%license LICENSE.txt
%{python_sitearch}/deap
%{python_sitearch}/deap-%{version}.dist-info

%changelog
* Wed Apr  3 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add missing C++ compiler to BuildRequires.
- Switch to pyproject macros.
- Stop skipping tests.
* Sat Dec  2 2023 Dirk Müller <dmueller@suse.com>
- update to 1.4.1:
  * https://github.com/DEAP/deap/compare/1.3.2...1.4.1
- drop no2to3.patch, python-deap-python3.patch,
  python-deap-remove-nose.patch (upstream)
* Tue Mar  1 2022 Dirk Müller <dmueller@suse.com>
- add no2to3.patch for compatibility with newer setuptools
* Wed Apr 21 2021 Steve Kowalik <steven.kowalik@suse.com>
- Don't build for Python 3.6, due to no NumPy.
* Thu Sep 10 2020 pgajdos@suse.com
- remove nose, python3
- added patches
  fix https://github.com/DEAP/deap/pull/507
  + python-deap-python3.patch
  fix https://github.com/DEAP/deap/pull/507
  + python-deap-remove-nose.patch
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- Update to 1.3.1
  * Add Python 3.8 builds
  * Various documentation fixups
  * Added try except ImportError for collections.abc
  * The function itertools.repeat in bound.__init__ was called as
    'itertools.repeat', while the function was imported using
    'from itertools import repeat'
  * fix: first element of the pop is inserted twice
  * Use codecs for Python2 compat
* Wed Nov 20 2019 Todd R <toddrme2178@gmail.com>
- Initial version
